﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Tsi1.Api.Infrastructure;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;

namespace Tsi1.Api.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class CourseController : ControllerBase
    {
        private readonly ICourseService _courseService;

        public CourseController(ICourseService courseService)
        {
            _courseService = courseService;
        }

        [Authorize(Roles = UserTypes.Student + ", " + UserTypes.Professor)]
        [HttpGet("MyCourses")]
        public async Task<IActionResult> MyCourses()
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);
            var userType = HttpContext.User.Claims.FirstOrDefault(x => x.Type == ClaimTypes.Role).Value;

            var result = await _courseService.GetCoursePreviews(userId, userType);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.FacultyAdmin)]
        [HttpPost("Create")]
        public async Task<IActionResult> Create(CourseCreateDto newCourse)
        {
            var tenantId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "TenantId").Value);

            newCourse.TenantId = tenantId;

            var result = await _courseService.Create(newCourse);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }


        [Authorize(Roles = UserTypes.Student)]
        [HttpPost("Matriculate/{courseId}")]
        public async Task<IActionResult> Matriculate(int courseId)
        {
            var userId = int.Parse(HttpContext.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var result = await _courseService.Matriculate(userId, courseId);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }

        [Authorize(Roles = UserTypes.FacultyAdmin)]
        [HttpPost("AddProfessorToCourse")]
        public async Task<IActionResult> AddProfessorToCourse(ProfessorCourseDto professorCourseDto)
        {
            var result = await _courseService.AddProfessorToCourse(professorCourseDto);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }
    }
}
